@@ -505,10 +505,8 @@ def test_addSimplifiedOutputVariables(IDFobject):
     assert len(outputmeterlist) == 0
 
     addittionaloutputs = ['Zone Thermostat Operative Temperature',
-                          'VRF Heat Pump Cooling Electricity Energy',
-                          'VRF Heat Pump Heating Electricity Energy',
-                          'Facility Total HVAC Electric Demand Power',
-                          'Facility Total HVAC Electricity Demand Rate'
+                          'Cooling Coil Total Cooling Rate',
+                          'Heating Coil Heating Rate',
                           ]
     for addittionaloutput in addittionaloutputs:
         outputvariable = ([x
